# Generated by Django 3.1.2 on 2021-02-24 10:21

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('reduction_viewer', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='reductionrun',
            name='cancel',
        ),
    ]
