# Generated by Django 3.1.2 on 2021-03-16 14:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('reduction_viewer', '0003_auto_20210310_1601'),
    ]

    operations = [
        migrations.AddField(
            model_name='instrument',
            name='is_flat_output',
            field=models.BooleanField(default=False),
        ),
    ]
