# Generated by Django 3.2.4 on 2021-10-08 17:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('instrument', '0004_auto_20210426_1600'),
        ('reduction_viewer', '0011_move_arguments_into_reductionarguments'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='runvariable',
            name='reduction_run',
        ),
        migrations.RemoveField(
            model_name='runvariable',
            name='variable',
        ),
        migrations.DeleteModel(name='InstrumentVariable', ),
        migrations.DeleteModel(name='RunVariable', ),
        migrations.DeleteModel(name='Variable', ),
    ]
