# Generated by Django 3.1.2 on 2021-04-26 14:28

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('instrument', '0002_auto_20210426_1519'),
        ('instrument', '0002_alter_variable_value'),
    ]

    operations = [
    ]
