# Generated by Django 3.2.4 on 2021-10-12 09:43

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('reduction_viewer', '0013_remove_reductionrun_retry_when'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='output',
            name='job',
        ),
        migrations.RemoveField(
            model_name='output',
            name='type',
        ),
        migrations.DeleteModel(
            name='Setting',
        ),
        migrations.DeleteModel(
            name='Output',
        ),
        migrations.DeleteModel(
            name='OutputType',
        ),
    ]
