# Generated by Django 3.2.4 on 2021-08-19 14:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('reduction_viewer', '0007_make_run_number_one_to_many'),
    ]

    operations = [
        migrations.AddField(
            model_name='reductionrun',
            name='batch_run',
            field=models.BooleanField(default=False),
        ),
    ]
