# Generated by Django 3.2.8 on 2021-10-11 11:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('reduction_viewer', '0008_reductionrun_batch_run'),
    ]

    operations = [
        migrations.AddField(
            model_name='reductionrun',
            name='run_title',
            field=models.CharField(blank=True, max_length=200),
        ),
    ]
